@@ -1,33 +1,31 @@
-#' @export
 slice.v12 <-
-function(level3 =.3, theta=30, phi=10, inc=25, lseq=100, static=FALSE, ticktype="detailed", diagnose=FALSE, verbose=TRUE)
+function(level3 =.3, theta=30, phi=10, inc=25, lseq=100, ticktype="detailed", diagnose=FALSE, verbose=TRUE)
 {
 	#					slice.v12
 	#
 	# VALUE	Rotatable plot of slice with fixed value of off-diagonal variable in positive definite 2 x 2 matrix.
 	#			Output includes list of latest settings of plot.
 	#
-	# INPUT		level3		Value of V12 (0 < level3 < 1)
+	# INPUT	level3	Value of V12 (0 < level3 < 1)
 	#		theta, phi	Initial angles of rotation of plot
 	#		inc		Increment in angle of rotation of plot
 	#		lseq		Number of points in each of x and y
-	#		static		Logical. TRUE suppresses rotation.
 	#		ticktype	Character: "simple" draws just an arrow parallel to the axis to indicate direction of increase; 
 	#					"detailed" draws normal ticks as per 2D plots.
 	#
-	#		diagnose	Logical. TRUE causes printing of diagnostic content
-	#		verbose	Logical. TRUE causes printing of program ID before and after running.
+	#		diagnose	Logical. T causes printing of diagnostic content
+	#		verbose	Logical. T causes printing of program ID before and after running.
 	#
 	MC <- match.call()
 	if(verbose) {
-		print("", quote = FALSE)
-		print("Running slice.v12", quote = FALSE)
-		print("", quote = FALSE)
-		print(date(), quote = FALSE)
-		print("", quote = FALSE)
-		print("Call:", quote = FALSE)
+		print("", quote = F)
+		print("Running slice.v12", quote = F)
+		print("", quote = F)
+		print(date(), quote = F)
+		print("", quote = F)
+		print("Call:", quote = F)
 		print(MC)
-		print("", quote = FALSE)
+		print("", quote = F)
 	}
 	######################################################
 	# Function relating off-diagonal element to diagonal #
@@ -51,9 +49,7 @@ function(level3 =.3, theta=30, phi=10, inc=25, lseq=100, static=FALSE, ticktype=
 	}
 	z[1,1] <- 1
 	z[1,2] <- 0
-	oldpar <- graphics::par(no.readonly=TRUE)
-	on.exit(graphics::par(oldpar))
-	graphics::par(bg = "white")
+	oldpar <- graphics::par(bg = "white")
 	#
 	#################################################################
 	# Cycle in order to allow interactive input on rotation of plot #
@@ -65,21 +61,16 @@ function(level3 =.3, theta=30, phi=10, inc=25, lseq=100, static=FALSE, ticktype=
 	 	graphics::persp(x, y, z, theta = td, phi = ph, expand = 0.5, col = "lightblue",ticktype="detailed",xlab="V1",ylab="V2",zlab="V12")
 		graphics::title(sub=".")## work around persp+plotmath bug
  		graphics::title(main = mt)
-		if(static){
-			message("You ran this graph in static mode. To view a rotatable version, set static=FALSE")
-			vv <- "x"
-		}else{
-		print("Click on R Console and then",quote=FALSE)
-		print("", quote = FALSE)
-		print("press 'u' to roll view up", quote=FALSE)
-		print("      'd' to roll view down", quote=FALSE)
-		print("      'r' to roll view to right", quote=FALSE)
-		print("      'l' to roll view to left", quote=FALSE)
-		print("      'x' to fix position of graph", quote=FALSE)
-		print("", quote = FALSE)
-		print("After each letter, press 'Enter'", quote=FALSE)
+		print("Click on R Console and then",quote=F)
+		print("", quote = F)
+		print("press 'u' to roll view up", quote=F)
+		print("      'd' to roll view down", quote=F)
+		print("      'r' to roll view to right", quote=F)
+		print("      'l' to roll view to left", quote=F)
+		print("      'x' to exit program", quote=F)
+		print("", quote = F)
+		print("After each letter, press 'Enter'", quote=F)
 		vv <- readline("Waiting for you . . . ")
-		}
 		if(vv == "u") ph <- ph - inc
 		if(vv == "d") ph <- ph + inc
 		if(vv == "r") td <- td - inc
@@ -89,12 +80,14 @@ function(level3 =.3, theta=30, phi=10, inc=25, lseq=100, static=FALSE, ticktype=
 			break
 		}
 	}
+	graphics::par(oldpar)
+	#
 	if(verbose) {
-		print("", quote = FALSE)
-		print("Finished running slice.v12", quote = FALSE)
-		print("", quote = FALSE)
-		print(date(), quote = FALSE)
-		print("", quote = FALSE)
+		print("", quote = F)
+		print("Finished running slice.v12", quote = F)
+		print("", quote = F)
+		print(date(), quote = F)
+		print("", quote = F)
 	}
 	list(level3=level3, theta=td, phi=ph, inc=inc, lseq=lseq,ticktype=ticktype, Call=MC)
 }
